# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/tables.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.cloud.automl_v1beta1.proto import (
    classification_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    column_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_items_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_stats_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    ranges_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    temporal_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_temporal__pb2,
)
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/tables.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1\352\002\036Google::Cloud::AutoML::V1beta1"
    ),
    serialized_pb=_b(
        '\n.google/cloud/automl_v1beta1/proto/tables.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x36google/cloud/automl_v1beta1/proto/classification.proto\x1a\x33google/cloud/automl_v1beta1/proto/column_spec.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_items.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_stats.proto\x1a.google/cloud/automl_v1beta1/proto/ranges.proto\x1a\x30google/cloud/automl_v1beta1/proto/temporal.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\xb0\x03\n\x15TablesDatasetMetadata\x12\x1d\n\x15primary_table_spec_id\x18\x01 \x01(\t\x12\x1d\n\x15target_column_spec_id\x18\x02 \x01(\t\x12\x1d\n\x15weight_column_spec_id\x18\x03 \x01(\t\x12\x1d\n\x15ml_use_column_spec_id\x18\x04 \x01(\t\x12t\n\x1atarget_column_correlations\x18\x06 \x03(\x0b\x32P.google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry\x12\x35\n\x11stats_update_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1an\n\x1dTargetColumnCorrelationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.google.cloud.automl.v1beta1.CorrelationStats:\x02\x38\x01"\x89\x03\n\x13TablesModelMetadata\x12\x43\n\x12target_column_spec\x18\x02 \x01(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12K\n\x1ainput_feature_column_specs\x18\x03 \x03(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12\x1e\n\x16optimization_objective\x18\x04 \x01(\t\x12T\n\x18tables_model_column_info\x18\x05 \x03(\x0b\x32\x32.google.cloud.automl.v1beta1.TablesModelColumnInfo\x12%\n\x1dtrain_budget_milli_node_hours\x18\x06 \x01(\x03\x12#\n\x1btrain_cost_milli_node_hours\x18\x07 \x01(\x03\x12\x1e\n\x16\x64isable_early_stopping\x18\x0c \x01(\x08"\xe5\x01\n\x10TablesAnnotation\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x45\n\x13prediction_interval\x18\x04 \x01(\x0b\x32(.google.cloud.automl.v1beta1.DoubleRange\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\x12T\n\x18tables_model_column_info\x18\x03 \x03(\x0b\x32\x32.google.cloud.automl.v1beta1.TablesModelColumnInfo"j\n\x15TablesModelColumnInfo\x12\x18\n\x10\x63olumn_spec_name\x18\x01 \x01(\t\x12\x1b\n\x13\x63olumn_display_name\x18\x02 \x01(\t\x12\x1a\n\x12\x66\x65\x61ture_importance\x18\x03 \x01(\x02\x42\xa5\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1\xea\x02\x1eGoogle::Cloud::AutoML::V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_temporal__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY = _descriptor.Descriptor(
    name="TargetColumnCorrelationsEntry",
    full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=806,
    serialized_end=916,
)

_TABLESDATASETMETADATA = _descriptor.Descriptor(
    name="TablesDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="primary_table_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.primary_table_spec_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.target_column_spec_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="weight_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.weight_column_spec_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ml_use_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.ml_use_column_spec_id",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_column_correlations",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.target_column_correlations",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="stats_update_time",
            full_name="google.cloud.automl.v1beta1.TablesDatasetMetadata.stats_update_time",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=484,
    serialized_end=916,
)


_TABLESMODELMETADATA = _descriptor.Descriptor(
    name="TablesModelMetadata",
    full_name="google.cloud.automl.v1beta1.TablesModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="target_column_spec",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.target_column_spec",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_feature_column_specs",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.input_feature_column_specs",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="optimization_objective",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.optimization_objective",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables_model_column_info",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.tables_model_column_info",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_budget_milli_node_hours",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.train_budget_milli_node_hours",
            index=4,
            number=6,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="train_cost_milli_node_hours",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.train_cost_milli_node_hours",
            index=5,
            number=7,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="disable_early_stopping",
            full_name="google.cloud.automl.v1beta1.TablesModelMetadata.disable_early_stopping",
            index=6,
            number=12,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=919,
    serialized_end=1312,
)


_TABLESANNOTATION = _descriptor.Descriptor(
    name="TablesAnnotation",
    full_name="google.cloud.automl.v1beta1.TablesAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="prediction_interval",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.prediction_interval",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.value",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tables_model_column_info",
            full_name="google.cloud.automl.v1beta1.TablesAnnotation.tables_model_column_info",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1315,
    serialized_end=1544,
)


_TABLESMODELCOLUMNINFO = _descriptor.Descriptor(
    name="TablesModelColumnInfo",
    full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec_name",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.column_spec_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="column_display_name",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.column_display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feature_importance",
            full_name="google.cloud.automl.v1beta1.TablesModelColumnInfo.feature_importance",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1546,
    serialized_end=1652,
)

_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY.fields_by_name[
    "value"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2._CORRELATIONSTATS
)
_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY.containing_type = (
    _TABLESDATASETMETADATA
)
_TABLESDATASETMETADATA.fields_by_name[
    "target_column_correlations"
].message_type = _TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY
_TABLESDATASETMETADATA.fields_by_name[
    "stats_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLESMODELMETADATA.fields_by_name[
    "target_column_spec"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_TABLESMODELMETADATA.fields_by_name[
    "input_feature_column_specs"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_TABLESMODELMETADATA.fields_by_name[
    "tables_model_column_info"
].message_type = _TABLESMODELCOLUMNINFO
_TABLESANNOTATION.fields_by_name[
    "prediction_interval"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_ranges__pb2._DOUBLERANGE
)
_TABLESANNOTATION.fields_by_name[
    "value"
].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_TABLESANNOTATION.fields_by_name[
    "tables_model_column_info"
].message_type = _TABLESMODELCOLUMNINFO
DESCRIPTOR.message_types_by_name["TablesDatasetMetadata"] = _TABLESDATASETMETADATA
DESCRIPTOR.message_types_by_name["TablesModelMetadata"] = _TABLESMODELMETADATA
DESCRIPTOR.message_types_by_name["TablesAnnotation"] = _TABLESANNOTATION
DESCRIPTOR.message_types_by_name["TablesModelColumnInfo"] = _TABLESMODELCOLUMNINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TablesDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TablesDatasetMetadata",
    (_message.Message,),
    dict(
        TargetColumnCorrelationsEntry=_reflection.GeneratedProtocolMessageType(
            "TargetColumnCorrelationsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.tables_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesDatasetMetadata.TargetColumnCorrelationsEntry)
            ),
        ),
        DESCRIPTOR=_TABLESDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Metadata for a dataset used for AutoML Tables.
  
  
  Attributes:
      primary_table_spec_id:
          Output only. The table\_spec\_id of the primary table of this
          dataset.
      target_column_spec_id:
          column\_spec\_id of the primary table's column that should be
          used as the training & prediction target. This column must be
          non-nullable and have one of following data types (otherwise
          model creation will error):  -  CATEGORY  -  FLOAT64  If the
          type is CATEGORY , only up to 100 unique values may exist in
          that column across all rows.  NOTE: Updates of this field will
          instantly affect any other users concurrently working with the
          dataset.
      weight_column_spec_id:
          column\_spec\_id of the primary table's column that should be
          used as the weight column, i.e. the higher the value the more
          important the row will be during model training. Required
          type: FLOAT64. Allowed values: 0 to 10000, inclusive on both
          ends; 0 means the row is ignored for training. If not set all
          rows are assumed to have equal weight of 1. NOTE: Updates of
          this field will instantly affect any other users concurrently
          working with the dataset.
      ml_use_column_spec_id:
          column\_spec\_id of the primary table column which specifies a
          possible ML use of the row, i.e. the column will be used to
          split the rows into TRAIN, VALIDATE and TEST sets. Required
          type: STRING. This column, if set, must either have all of
          ``TRAIN``, ``VALIDATE``, ``TEST`` among its values, or only
          have ``TEST``, ``UNASSIGNED`` values. In the latter case the
          rows with ``UNASSIGNED`` value will be assigned by AutoML.
          Note that if a given ml use distribution makes it impossible
          to create a "good" model, that call will error describing the
          issue. If both this column\_spec\_id and primary table's
          time\_column\_spec\_id are not set, then all rows are treated
          as ``UNASSIGNED``. NOTE: Updates of this field will instantly
          affect any other users concurrently working with the dataset.
      target_column_correlations:
          Output only. Correlations between  [TablesDatasetMetadata.targ
          et\_column\_spec\_id][google.cloud.automl.v1beta1.TablesDatase
          tMetadata.target\_column\_spec\_id], and other columns of the
          [TablesDatasetMetadataprimary\_table][google.cloud.automl.v1be
          ta1.TablesDatasetMetadata.primary\_table\_spec\_id]. Only set
          if the target column is set. Mapping from other column spec id
          to its CorrelationStats with the target column. This field may
          be stale, see the stats\_update\_time field for for the
          timestamp at which these stats were last updated.
      stats_update_time:
          Output only. The most recent timestamp when
          target\_column\_correlations field and all descendant
          ColumnSpec.data\_stats and ColumnSpec.top\_correlated\_columns
          fields were last (re-)generated. Any changes that happened to
          the dataset afterwards are not reflected in these fields
          values. The regeneration happens in the background on a best
          effort basis.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TablesDatasetMetadata)
_sym_db.RegisterMessage(TablesDatasetMetadata.TargetColumnCorrelationsEntry)

TablesModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TablesModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Model metadata specific to AutoML Tables.
  
  
  Attributes:
      target_column_spec:
          Column spec of the dataset's primary table's column the model
          is predicting. Snapshotted when model creation started. Only 3
          fields are used: name - May be set on CreateModel, if it's not
          then the ColumnSpec corresponding to the current
          target\_column\_spec\_id of the dataset the model is trained
          from is used. If neither is set, CreateModel will error.
          display\_name - Output only. data\_type - Output only.
      input_feature_column_specs:
          Column specs of the dataset's primary table's columns, on
          which the model is trained and which are used as the input for
          predictions. The  [target\_column][google.cloud.automl.v1beta1
          .TablesModelMetadata.target\_column\_spec] as well as,
          according to dataset's state upon model creation,  [weight\_co
          lumn][google.cloud.automl.v1beta1.TablesDatasetMetadata.weight
          \_column\_spec\_id], and  [ml\_use\_column][google.cloud.autom
          l.v1beta1.TablesDatasetMetadata.ml\_use\_column\_spec\_id]
          must never be included here.  Only 3 fields are used:  -  name
          - May be set on CreateModel, if set only the columns specified
          are used, otherwise all primary table's columns (except the
          ones    listed above) are used for the training and prediction
          input.  -  display\_name - Output only.  -  data\_type -
          Output only.
      optimization_objective:
          Objective function the model is optimizing towards. The
          training process creates a model that maximizes/minimizes the
          value of the objective function over the validation set.  The
          supported optimization objectives depend on the prediction
          type. If the field is not set, a default objective function is
          used.  CLASSIFICATION\_BINARY: "MAXIMIZE\_AU\_ROC" (default) -
          Maximize the area under the receiver operating characteristic
          (ROC) curve. "MINIMIZE\_LOG\_LOSS" - Minimize log loss.
          "MAXIMIZE\_AU\_PRC" - Maximize the area under the precision-
          recall curve. "MAXIMIZE\_PRECISION\_AT\_RECALL" - Maximize
          precision for a specified recall value.
          "MAXIMIZE\_RECALL\_AT\_PRECISION" - Maximize recall for a
          specified precision value.  CLASSIFICATION\_MULTI\_CLASS :
          "MINIMIZE\_LOG\_LOSS" (default) - Minimize log loss.
          REGRESSION: "MINIMIZE\_RMSE" (default) - Minimize root-mean-
          squared error (RMSE). "MINIMIZE\_MAE" - Minimize mean-absolute
          error (MAE). "MINIMIZE\_RMSLE" - Minimize root-mean-squared
          log error (RMSLE).
      tables_model_column_info:
          Output only. Auxiliary information for each of the
          input\_feature\_column\_specs with respect to this particular
          model.
      train_budget_milli_node_hours:
          Required. The train budget of creating this model, expressed
          in milli node hours i.e. 1,000 value in this field means 1
          node hour.  The training cost of the model will not exceed
          this budget. The final cost will be attempted to be close to
          the budget, though may end up being (even) noticeably smaller
          - at the backend's discretion. This especially may happen when
          further model training ceases to provide any improvements.  If
          the budget is set to a value known to be insufficient to train
          a model for the given dataset, the training won't be attempted
          and will error.  The train budget must be between 1,000 and
          72,000 milli node hours, inclusive.
      train_cost_milli_node_hours:
          Output only. The actual training cost of the model, expressed
          in milli node hours, i.e. 1,000 value in this field means 1
          node hour. Guaranteed to not exceed the train budget.
      disable_early_stopping:
          Use the entire training budget. This disables the early
          stopping feature. By default, the early stopping feature is
          enabled, which means that AutoML Tables might stop training
          before the entire training budget has been used.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesModelMetadata)
    ),
)
_sym_db.RegisterMessage(TablesModelMetadata)

TablesAnnotation = _reflection.GeneratedProtocolMessageType(
    "TablesAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""Contains annotation details specific to Tables.
  
  
  Attributes:
      score:
          Output only. A confidence estimate between 0.0 and 1.0,
          inclusive. A higher value means greater confidence in the
          returned value. For  [target\_column\_spec][google.cloud.autom
          l.v1beta1.TablesModelMetadata.target\_column\_spec] of FLOAT64
          data type the score is not populated.
      prediction_interval:
          Output only. Only populated when  [target\_column\_spec][googl
          e.cloud.automl.v1beta1.TablesModelMetadata.target\_column\_spe
          c] has FLOAT64 data type. An interval in which the exactly
          correct target value has 95% chance to be in.
      value:
          The predicted value of the row's  [target\_column][google.clou
          d.automl.v1beta1.TablesModelMetadata.target\_column\_spec].
          The value depends on the column's DataType:  -  CATEGORY - the
          predicted (with the above confidence ``score``)    CATEGORY
          value.  -  FLOAT64 - the predicted (with above
          ``prediction_interval``) FLOAT64    value.
      tables_model_column_info:
          Output only. Auxiliary information for each of the model's  [i
          nput\_feature\_column\_specs][google.cloud.automl.v1beta1.Tabl
          esModelMetadata.input\_feature\_column\_specs] with respect to
          this particular prediction. If no other fields than  [column\_
          spec\_name][google.cloud.automl.v1beta1.TablesModelColumnInfo.
          column\_spec\_name] and  [column\_display\_name][google.cloud.
          automl.v1beta1.TablesModelColumnInfo.column\_display\_name]
          would be populated, then this whole field is not.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesAnnotation)
    ),
)
_sym_db.RegisterMessage(TablesAnnotation)

TablesModelColumnInfo = _reflection.GeneratedProtocolMessageType(
    "TablesModelColumnInfo",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESMODELCOLUMNINFO,
        __module__="google.cloud.automl_v1beta1.proto.tables_pb2",
        __doc__="""An information specific to given column and Tables Model, in context of
  the Model and the predictions created by it.
  
  
  Attributes:
      column_spec_name:
          Output only. The name of the ColumnSpec describing the column.
          Not populated when this proto is outputted to BigQuery.
      column_display_name:
          Output only. The display name of the column (same as the
          display\_name of its ColumnSpec).
      feature_importance:
          Output only. When given as part of a Model (always populated):
          Measurement of how much model predictions correctness on the
          TEST data depend on values in this column. A value between 0
          and 1, higher means higher influence. These values are
          normalized - for all input feature columns of a given model
          they add to 1.  When given back by Predict (populated iff
          [feature\_importance
          param][google.cloud.automl.v1beta1.PredictRequest.params] is
          set) or Batch Predict (populated iff [feature\_importance][goo
          gle.cloud.automl.v1beta1.PredictRequest.params] param is set):
          Measurement of how impactful for the prediction returned for
          the given row the value in this column was. A value between 0
          and 1, higher means larger impact. These values are normalized
          - for all input feature columns of a single predicted row they
          add to 1.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TablesModelColumnInfo)
    ),
)
_sym_db.RegisterMessage(TablesModelColumnInfo)


DESCRIPTOR._options = None
_TABLESDATASETMETADATA_TARGETCOLUMNCORRELATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.cloud.automl_v1beta1.proto import prediction_service_pb2_grpc


class PredictionServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.automl.v1beta1 PredictionService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self, channel=None, credentials=None, address="automl.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
                options={
                    "grpc.max_send_message_length": -1,
                    "grpc.max_receive_message_length": -1,
                }.items(),
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            "prediction_service_stub": prediction_service_pb2_grpc.PredictionServiceStub(
                channel
            )
        }

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(
            channel
        )

    @classmethod
    def create_channel(
        cls, address="automl.googleapis.com:443", credentials=None, **kwargs
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES, **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def predict(self):
        """Return the gRPC stub for :meth:`PredictionServiceClient.predict`.

        Perform an online prediction. The prediction result will be directly
        returned in the response. Available for following ML problems, and their
        expected request payloads:

        -  Image Classification - Image in .JPEG, .GIF or .PNG format,
           image\_bytes up to 30MB.
        -  Image Object Detection - Image in .JPEG, .GIF or .PNG format,
           image\_bytes up to 30MB.
        -  Text Classification - TextSnippet, content up to 60,000 characters,
           UTF-8 encoded.
        -  Text Extraction - TextSnippet, content up to 30,000 characters, UTF-8
           NFC encoded.
        -  Translation - TextSnippet, content up to 25,000 characters, UTF-8
           encoded.
        -  Tables - Row, with column values matching the columns of the model,
           up to 5MB. Not available for FORECASTING

        ``prediction_type``.

        -  Text Sentiment - TextSnippet, content up 500 characters, UTF-8
           encoded.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["prediction_service_stub"].Predict

    @property
    def batch_predict(self):
        """Return the gRPC stub for :meth:`PredictionServiceClient.batch_predict`.

        Perform a batch prediction. Unlike the online ``Predict``, batch
        prediction result won't be immediately available in the response.
        Instead, a long running operation object is returned. User can poll the
        operation result via ``GetOperation`` method. Once the operation is
        done, ``BatchPredictResult`` is returned in the ``response`` field.
        Available for following ML problems:

        -  Image Classification
        -  Image Object Detection
        -  Video Classification
        -  Video Object Tracking \* Text Extraction
        -  Tables

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["prediction_service_stub"].BatchPredict



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import

from google.cloud.automl_v1beta1 import types
from google.cloud.automl_v1beta1.gapic import auto_ml_client
from google.cloud.automl_v1beta1.gapic import enums
from google.cloud.automl_v1beta1.gapic import prediction_service_client
from google.cloud.automl_v1beta1.tables import gcs_client
from google.cloud.automl_v1beta1.tables import tables_client


class TablesClient(tables_client.TablesClient):
    __doc__ = tables_client.TablesClient.__doc__


class AutoMlClient(auto_ml_client.AutoMlClient):
    __doc__ = auto_ml_client.AutoMlClient.__doc__
    enums = enums


class PredictionServiceClient(prediction_service_client.PredictionServiceClient):
    __doc__ = prediction_service_client.PredictionServiceClient.__doc__
    enums = enums


class GcsClient(gcs_client.GcsClient):
    __doc__ = gcs_client.GcsClient.__doc__


__all__ = (
    "enums",
    "types",
    "AutoMlClient",
    "PredictionServiceClient",
    "TablesClient",
    "GcsClient",
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/data_items.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    geometry_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    text_segment_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/data_items.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1\352\002\036Google::Cloud::AutoML::V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/data_items.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x30google/cloud/automl_v1beta1/proto/geometry.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a\x34google/cloud/automl_v1beta1/proto/text_segment.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto"\x7f\n\x05Image\x12\x15\n\x0bimage_bytes\x18\x01 \x01(\x0cH\x00\x12@\n\x0cinput_config\x18\x06 \x01(\x0b\x32(.google.cloud.automl.v1beta1.InputConfigH\x00\x12\x15\n\rthumbnail_uri\x18\x04 \x01(\tB\x06\n\x04\x64\x61ta"F\n\x0bTextSnippet\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\tmime_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x04 \x01(\t"\xef\x01\n\x12\x44ocumentDimensions\x12S\n\x04unit\x18\x01 \x01(\x0e\x32\x45.google.cloud.automl.v1beta1.DocumentDimensions.DocumentDimensionUnit\x12\r\n\x05width\x18\x02 \x01(\x02\x12\x0e\n\x06height\x18\x03 \x01(\x02"e\n\x15\x44ocumentDimensionUnit\x12\'\n#DOCUMENT_DIMENSION_UNIT_UNSPECIFIED\x10\x00\x12\x08\n\x04INCH\x10\x01\x12\x0e\n\nCENTIMETER\x10\x02\x12\t\n\x05POINT\x10\x03"\xf9\x05\n\x08\x44ocument\x12\x46\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x30.google.cloud.automl.v1beta1.DocumentInputConfig\x12?\n\rdocument_text\x18\x02 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSnippet\x12<\n\x06layout\x18\x03 \x03(\x0b\x32,.google.cloud.automl.v1beta1.Document.Layout\x12L\n\x13\x64ocument_dimensions\x18\x04 \x01(\x0b\x32/.google.cloud.automl.v1beta1.DocumentDimensions\x12\x12\n\npage_count\x18\x05 \x01(\x05\x1a\xc3\x03\n\x06Layout\x12>\n\x0ctext_segment\x18\x01 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSegment\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12@\n\rbounding_poly\x18\x03 \x01(\x0b\x32).google.cloud.automl.v1beta1.BoundingPoly\x12W\n\x11text_segment_type\x18\x04 \x01(\x0e\x32<.google.cloud.automl.v1beta1.Document.Layout.TextSegmentType"\xc8\x01\n\x0fTextSegmentType\x12!\n\x1dTEXT_SEGMENT_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TOKEN\x10\x01\x12\r\n\tPARAGRAPH\x10\x02\x12\x0e\n\nFORM_FIELD\x10\x03\x12\x13\n\x0f\x46ORM_FIELD_NAME\x10\x04\x12\x17\n\x13\x46ORM_FIELD_CONTENTS\x10\x05\x12\t\n\x05TABLE\x10\x06\x12\x10\n\x0cTABLE_HEADER\x10\x07\x12\r\n\tTABLE_ROW\x10\x08\x12\x0e\n\nTABLE_CELL\x10\t"F\n\x03Row\x12\x17\n\x0f\x63olumn_spec_ids\x18\x02 \x03(\t\x12&\n\x06values\x18\x03 \x03(\x0b\x32\x16.google.protobuf.Value"\xfe\x01\n\x0e\x45xamplePayload\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32".google.cloud.automl.v1beta1.ImageH\x00\x12@\n\x0ctext_snippet\x18\x02 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSnippetH\x00\x12\x39\n\x08\x64ocument\x18\x04 \x01(\x0b\x32%.google.cloud.automl.v1beta1.DocumentH\x00\x12/\n\x03row\x18\x03 \x01(\x0b\x32 .google.cloud.automl.v1beta1.RowH\x00\x42\t\n\x07payloadB\xa5\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1\xea\x02\x1eGoogle::Cloud::AutoML::V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
    ],
)


_DOCUMENTDIMENSIONS_DOCUMENTDIMENSIONUNIT = _descriptor.EnumDescriptor(
    name="DocumentDimensionUnit",
    full_name="google.cloud.automl.v1beta1.DocumentDimensions.DocumentDimensionUnit",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DOCUMENT_DIMENSION_UNIT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="INCH", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CENTIMETER", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="POINT", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=690,
    serialized_end=791,
)
_sym_db.RegisterEnumDescriptor(_DOCUMENTDIMENSIONS_DOCUMENTDIMENSIONUNIT)

_DOCUMENT_LAYOUT_TEXTSEGMENTTYPE = _descriptor.EnumDescriptor(
    name="TextSegmentType",
    full_name="google.cloud.automl.v1beta1.Document.Layout.TextSegmentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TEXT_SEGMENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TOKEN", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PARAGRAPH", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FORM_FIELD", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FORM_FIELD_NAME",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FORM_FIELD_CONTENTS",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE_HEADER", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE_ROW", index=8, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE_CELL", index=9, number=9, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1355,
    serialized_end=1555,
)
_sym_db.RegisterEnumDescriptor(_DOCUMENT_LAYOUT_TEXTSEGMENTTYPE)


_IMAGE = _descriptor.Descriptor(
    name="Image",
    full_name="google.cloud.automl.v1beta1.Image",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image_bytes",
            full_name="google.cloud.automl.v1beta1.Image.image_bytes",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.Image.input_config",
            index=1,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="thumbnail_uri",
            full_name="google.cloud.automl.v1beta1.Image.thumbnail_uri",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="data",
            full_name="google.cloud.automl.v1beta1.Image.data",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=350,
    serialized_end=477,
)


_TEXTSNIPPET = _descriptor.Descriptor(
    name="TextSnippet",
    full_name="google.cloud.automl.v1beta1.TextSnippet",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="google.cloud.automl.v1beta1.TextSnippet.content",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mime_type",
            full_name="google.cloud.automl.v1beta1.TextSnippet.mime_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_uri",
            full_name="google.cloud.automl.v1beta1.TextSnippet.content_uri",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=479,
    serialized_end=549,
)


_DOCUMENTDIMENSIONS = _descriptor.Descriptor(
    name="DocumentDimensions",
    full_name="google.cloud.automl.v1beta1.DocumentDimensions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="unit",
            full_name="google.cloud.automl.v1beta1.DocumentDimensions.unit",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="width",
            full_name="google.cloud.automl.v1beta1.DocumentDimensions.width",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="google.cloud.automl.v1beta1.DocumentDimensions.height",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_DOCUMENTDIMENSIONS_DOCUMENTDIMENSIONUNIT],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=552,
    serialized_end=791,
)


_DOCUMENT_LAYOUT = _descriptor.Descriptor(
    name="Layout",
    full_name="google.cloud.automl.v1beta1.Document.Layout",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="text_segment",
            full_name="google.cloud.automl.v1beta1.Document.Layout.text_segment",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_number",
            full_name="google.cloud.automl.v1beta1.Document.Layout.page_number",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bounding_poly",
            full_name="google.cloud.automl.v1beta1.Document.Layout.bounding_poly",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_segment_type",
            full_name="google.cloud.automl.v1beta1.Document.Layout.text_segment_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_DOCUMENT_LAYOUT_TEXTSEGMENTTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1104,
    serialized_end=1555,
)

_DOCUMENT = _descriptor.Descriptor(
    name="Document",
    full_name="google.cloud.automl.v1beta1.Document",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.Document.input_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="document_text",
            full_name="google.cloud.automl.v1beta1.Document.document_text",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="layout",
            full_name="google.cloud.automl.v1beta1.Document.layout",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="document_dimensions",
            full_name="google.cloud.automl.v1beta1.Document.document_dimensions",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_count",
            full_name="google.cloud.automl.v1beta1.Document.page_count",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_DOCUMENT_LAYOUT],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=794,
    serialized_end=1555,
)


_ROW = _descriptor.Descriptor(
    name="Row",
    full_name="google.cloud.automl.v1beta1.Row",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec_ids",
            full_name="google.cloud.automl.v1beta1.Row.column_spec_ids",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="values",
            full_name="google.cloud.automl.v1beta1.Row.values",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1557,
    serialized_end=1627,
)


_EXAMPLEPAYLOAD = _descriptor.Descriptor(
    name="ExamplePayload",
    full_name="google.cloud.automl.v1beta1.ExamplePayload",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.image",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_snippet",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.text_snippet",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="document",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.document",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="row",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.row",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.payload",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1630,
    serialized_end=1884,
)

_IMAGE.fields_by_name[
    "input_config"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._INPUTCONFIG
_IMAGE.oneofs_by_name["data"].fields.append(_IMAGE.fields_by_name["image_bytes"])
_IMAGE.fields_by_name["image_bytes"].containing_oneof = _IMAGE.oneofs_by_name["data"]
_IMAGE.oneofs_by_name["data"].fields.append(_IMAGE.fields_by_name["input_config"])
_IMAGE.fields_by_name["input_config"].containing_oneof = _IMAGE.oneofs_by_name["data"]
_DOCUMENTDIMENSIONS.fields_by_name[
    "unit"
].enum_type = _DOCUMENTDIMENSIONS_DOCUMENTDIMENSIONUNIT
_DOCUMENTDIMENSIONS_DOCUMENTDIMENSIONUNIT.containing_type = _DOCUMENTDIMENSIONS
_DOCUMENT_LAYOUT.fields_by_name[
    "text_segment"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__segment__pb2._TEXTSEGMENT
)
_DOCUMENT_LAYOUT.fields_by_name[
    "bounding_poly"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2._BOUNDINGPOLY
)
_DOCUMENT_LAYOUT.fields_by_name[
    "text_segment_type"
].enum_type = _DOCUMENT_LAYOUT_TEXTSEGMENTTYPE
_DOCUMENT_LAYOUT.containing_type = _DOCUMENT
_DOCUMENT_LAYOUT_TEXTSEGMENTTYPE.containing_type = _DOCUMENT_LAYOUT
_DOCUMENT.fields_by_name[
    "input_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._DOCUMENTINPUTCONFIG
)
_DOCUMENT.fields_by_name["document_text"].message_type = _TEXTSNIPPET
_DOCUMENT.fields_by_name["layout"].message_type = _DOCUMENT_LAYOUT
_DOCUMENT.fields_by_name["document_dimensions"].message_type = _DOCUMENTDIMENSIONS
_ROW.fields_by_name["values"].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_EXAMPLEPAYLOAD.fields_by_name["image"].message_type = _IMAGE
_EXAMPLEPAYLOAD.fields_by_name["text_snippet"].message_type = _TEXTSNIPPET
_EXAMPLEPAYLOAD.fields_by_name["document"].message_type = _DOCUMENT
_EXAMPLEPAYLOAD.fields_by_name["row"].message_type = _ROW
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["image"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "image"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["text_snippet"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "text_snippet"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["document"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "document"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["row"]
)
_EXAMPLEPAYLOAD.fields_by_name["row"].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name[
    "payload"
]
DESCRIPTOR.message_types_by_name["Image"] = _IMAGE
DESCRIPTOR.message_types_by_name["TextSnippet"] = _TEXTSNIPPET
DESCRIPTOR.message_types_by_name["DocumentDimensions"] = _DOCUMENTDIMENSIONS
DESCRIPTOR.message_types_by_name["Document"] = _DOCUMENT
DESCRIPTOR.message_types_by_name["Row"] = _ROW
DESCRIPTOR.message_types_by_name["ExamplePayload"] = _EXAMPLEPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType(
    "Image",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGE,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of an image. Only images up to 30MB in size are
  supported.
  
  
  Attributes:
      data:
          Input only. The data representing the image. For Predict calls
          [image\_bytes][] must be set, as other options are not
          currently supported by prediction API. You can read the
          contents of an uploaded image by using the [content\_uri][]
          field.
      image_bytes:
          Image content represented as a stream of bytes. Note: As with
          all ``bytes`` fields, protobuffers use a pure binary
          representation, whereas JSON representations use base64.
      input_config:
          An input config specifying the content of the image.
      thumbnail_uri:
          Output only. HTTP URI to the thumbnail image.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Image)
    ),
)
_sym_db.RegisterMessage(Image)

TextSnippet = _reflection.GeneratedProtocolMessageType(
    "TextSnippet",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSNIPPET,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of a text snippet.
  
  
  Attributes:
      content:
          Required. The content of the text snippet as a string. Up to
          250000 characters long.
      mime_type:
          Optional. The format of
          [content][google.cloud.automl.v1beta1.TextSnippet.content].
          Currently the only two allowed values are "text/html" and
          "text/plain". If left blank, the format is automatically
          determined from the type of the uploaded
          [content][google.cloud.automl.v1beta1.TextSnippet.content].
      content_uri:
          Output only. HTTP URI where you can download the content.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSnippet)
    ),
)
_sym_db.RegisterMessage(TextSnippet)

DocumentDimensions = _reflection.GeneratedProtocolMessageType(
    "DocumentDimensions",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DOCUMENTDIMENSIONS,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""Message that describes dimension of a document.
  
  
  Attributes:
      unit:
          Unit of the dimension.
      width:
          Width value of the document, works together with the unit.
      height:
          Height value of the document, works together with the unit.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DocumentDimensions)
    ),
)
_sym_db.RegisterMessage(DocumentDimensions)

Document = _reflection.GeneratedProtocolMessageType(
    "Document",
    (_message.Message,),
    dict(
        Layout=_reflection.GeneratedProtocolMessageType(
            "Layout",
            (_message.Message,),
            dict(
                DESCRIPTOR=_DOCUMENT_LAYOUT,
                __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
                __doc__="""Describes the layout information of a
    [text\_segment][google.cloud.automl.v1beta1.Document.Layout.text\_segment]
    in the document.
    
    
    Attributes:
        text_segment:
            Text Segment that represents a segment in [document\_text][goo
            gle.cloud.automl.v1beta1.Document.document\_text].
        page_number:
            Page number of the [text\_segment][google.cloud.automl.v1beta1
            .Document.Layout.text\_segment] in the original document,
            starts from 1.
        bounding_poly:
            The position of the [text\_segment][google.cloud.automl.v1beta
            1.Document.Layout.text\_segment] in the page. Contains exactly
            4  [normalized\_vertices][google.cloud.automl.v1beta1.Bounding
            Poly.normalized\_vertices] and they are connected by edges in
            the order provided, which will represent a rectangle parallel
            to the frame. The [NormalizedVertex-s][google.cloud.automl.v1b
            eta1.NormalizedVertex] are relative to the page. Coordinates
            are based on top-left as point (0,0).
        text_segment_type:
            The type of the [text\_segment][google.cloud.automl.v1beta1.Do
            cument.Layout.text\_segment] in document.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Document.Layout)
            ),
        ),
        DESCRIPTOR=_DOCUMENT,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A structured text document e.g. a PDF.
  
  
  Attributes:
      input_config:
          An input config specifying the content of the document.
      document_text:
          The plain text version of this document.
      layout:
          Describes the layout of the document. Sorted by
          [page\_number][].
      document_dimensions:
          The dimensions of the page in the document.
      page_count:
          Number of pages in the document.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Document)
    ),
)
_sym_db.RegisterMessage(Document)
_sym_db.RegisterMessage(Document.Layout)

Row = _reflection.GeneratedProtocolMessageType(
    "Row",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ROW,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of a row in a relational table.
  
  
  Attributes:
      column_spec_ids:
          The resource IDs of the column specs describing the columns of
          the row. If set must contain, but possibly in a different
          order, all input feature  [column\_spec\_ids][google.cloud.aut
          oml.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
          of the Model this row is being passed to. Note: The below
          ``values`` field must match order of this field, if this field
          is set.
      values:
          Required. The values of the row cells, given in the same order
          as the column\_spec\_ids, or, if not set, then in the same
          order as input feature  [column\_specs][google.cloud.automl.v1
          beta1.TablesModelMetadata.input\_feature\_column\_specs] of
          the Model this row is being passed to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Row)
    ),
)
_sym_db.RegisterMessage(Row)

ExamplePayload = _reflection.GeneratedProtocolMessageType(
    "ExamplePayload",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXAMPLEPAYLOAD,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""Example data used for training or prediction.
  
  
  Attributes:
      payload:
          Required. Input only. The example data.
      image:
          Example image.
      text_snippet:
          Example text.
      document:
          Example document.
      row:
          Example relational table row.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExamplePayload)
    ),
)
_sym_db.RegisterMessage(ExamplePayload)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class ClassificationType(enum.IntEnum):
    """
    Type of the classification problem.

    Attributes:
      CLASSIFICATION_TYPE_UNSPECIFIED (int): An un-set value of this enum.
      MULTICLASS (int): At most one label is allowed per example.
      MULTILABEL (int): Multiple labels are allowed for one example.
    """

    CLASSIFICATION_TYPE_UNSPECIFIED = 0
    MULTICLASS = 1
    MULTILABEL = 2


class NullValue(enum.IntEnum):
    """
    ``NullValue`` is a singleton enumeration to represent the null value for
    the ``Value`` type union.

    The JSON representation for ``NullValue`` is JSON ``null``.

    Attributes:
      NULL_VALUE (int): Null value.
    """

    NULL_VALUE = 0


class TypeCode(enum.IntEnum):
    """
    ``TypeCode`` is used as a part of ``DataType``.

    Attributes:
      TYPE_CODE_UNSPECIFIED (int): Not specified. Should not be used.
      FLOAT64 (int): Encoded as ``number``, or the strings ``"NaN"``, ``"Infinity"``, or
      ``"-Infinity"``.
      TIMESTAMP (int): Must be between 0AD and 9999AD. Encoded as ``string`` according to
      ``time_format``, or, if that format is not set, then in RFC 3339
      ``date-time`` format, where ``time-offset`` = ``"Z"`` (e.g.
      1985-04-12T23:20:50.52Z).
      STRING (int): Encoded as ``string``.
      ARRAY (int): Encoded as ``list``, where the list elements are represented according
      to

      ``list_element_type``.
      STRUCT (int): Encoded as ``struct``, where field values are represented according to
      ``struct_type``.
      CATEGORY (int): Values of this type are not further understood by AutoML, e.g. AutoML is
      unable to tell the order of values (as it could with FLOAT64), or is
      unable to say if one value contains another (as it could with STRING).
      Encoded as ``string`` (bytes should be base64-encoded, as described in
      RFC 4648, section 4).
    """

    TYPE_CODE_UNSPECIFIED = 0
    FLOAT64 = 3
    TIMESTAMP = 4
    STRING = 6
    ARRAY = 8
    STRUCT = 9
    CATEGORY = 10


class Document(object):
    class Layout(object):
        class TextSegmentType(enum.IntEnum):
            """
            The type of TextSegment in the context of the original document.

            Attributes:
              TEXT_SEGMENT_TYPE_UNSPECIFIED (int): Should not be used.
              TOKEN (int): The text segment is a token. e.g. word.
              PARAGRAPH (int): The text segment is a paragraph.
              FORM_FIELD (int): The text segment is a form field.
              FORM_FIELD_NAME (int): The text segment is the name part of a form field. It will be treated as
              child of another FORM\_FIELD TextSegment if its span is subspan of
              another TextSegment with type FORM\_FIELD.
              FORM_FIELD_CONTENTS (int): The text segment is the text content part of a form field. It will be
              treated as child of another FORM\_FIELD TextSegment if its span is
              subspan of another TextSegment with type FORM\_FIELD.
              TABLE (int): The text segment is a whole table, including headers, and all rows.
              TABLE_HEADER (int): The text segment is a table's headers. It will be treated as child of
              another TABLE TextSegment if its span is subspan of another TextSegment
              with type TABLE.
              TABLE_ROW (int): The text segment is a row in table. It will be treated as child of
              another TABLE TextSegment if its span is subspan of another TextSegment
              with type TABLE.
              TABLE_CELL (int): The text segment is a cell in table. It will be treated as child of
              another TABLE\_ROW TextSegment if its span is subspan of another
              TextSegment with type TABLE\_ROW.
            """

            TEXT_SEGMENT_TYPE_UNSPECIFIED = 0
            TOKEN = 1
            PARAGRAPH = 2
            FORM_FIELD = 3
            FORM_FIELD_NAME = 4
            FORM_FIELD_CONTENTS = 5
            TABLE = 6
            TABLE_HEADER = 7
            TABLE_ROW = 8
            TABLE_CELL = 9


class DocumentDimensions(object):
    class DocumentDimensionUnit(enum.IntEnum):
        """
        Unit of the document dimension.

        Attributes:
          DOCUMENT_DIMENSION_UNIT_UNSPECIFIED (int): Should not be used.
          INCH (int): Document dimension is measured in inches.
          CENTIMETER (int): Document dimension is measured in centimeters.
          POINT (int): Document dimension is measured in points. 72 points = 1 inch.
        """

        DOCUMENT_DIMENSION_UNIT_UNSPECIFIED = 0
        INCH = 1
        CENTIMETER = 2
        POINT = 3


class Model(object):
    class DeploymentState(enum.IntEnum):
        """
        Deployment state of the model.

        Attributes:
          DEPLOYMENT_STATE_UNSPECIFIED (int): Should not be used, an un-set enum has this value by default.
          DEPLOYED (int): Model is deployed.
          UNDEPLOYED (int): Model is not deployed.
        """

        DEPLOYMENT_STATE_UNSPECIFIED = 0
        DEPLOYED = 1
        UNDEPLOYED = 2
